/services/content_creator_insights_service.proto

--- v22/services/content_creator_insights_service.proto 2026-03-19 17:16:00.000000000 +0000
+++ v23/services/content_creator_insights_service.proto 2026-03-19 17:16:06.000000000 +0000
@@ -92,10 +93,32 @@
     // is used to search for creators whose own viewers match the input
     // audience. Attributes age_range, gender, user_interest, entity, category,
     // device, parental_status, and income_range are supported. Attribute
-    // location is not supported.
-    repeated google.ads.googleads.v22.common.AudienceInsightsAttribute
+    // location is not supported. Attributes user_interest, entity, and category
+    // can only be set in audience_attributes when audience_combinations is
+    // unused.
+    repeated google.ads.googleads.v23.common.AudienceInsightsAttribute
         audience_attributes = 1 [(google.api.field_behavior) = OPTIONAL];

+    // Optional. A list of audience attribute groups consisting of one or more
+    // Knowledge Graph entities, Product & Service Categories and user interests
+    // that describes an audience. The groups have a logical AND-of-ORs
+    // structure:
+    //
+    // 1. Attributes within each InsightsAudienceAttributeGroup are combined
+    // with OR.
+    //
+    // 2. The groups themselves are combined together with AND.
+    //
+    // For example, an audience (Interest A OR Interest B) AND (Entity C) is
+    // represented using two groups. The first group contains the two interests
+    // and the second group contains the entity.
+    //
+    // This field cannot be set if any Knowledge Graph entities, Product &
+    // Service Categories, or user interests are specified in
+    // audience_attributes.
+    repeated google.ads.googleads.v23.common.InsightsAudienceAttributeGroup
+        audience_combinations = 3 [(google.api.field_behavior) = OPTIONAL];
+
     // Optional. Creator attributes that describe a collection of types of
     // content. This is used to search for creators whose content matches the
     // input creator attributes. Only Knowledge Graph Entities tagged with
@@ -280,6 +303,10 @@
   // See https://support.google.com/google-ads/answer/13828964 for more
   // information about BrandConnect.
   bool is_brand_connect_creator = 15;
+
+  // Partnership opportunities available for this creator.
+  repeated google.ads.googleads.v23.enums.PartnershipOpportunityEnum
+      .PartnershipOpportunity partnership_opportunities = 17;
 }

 // YouTube Channel insights, and its metadata (such as channel name and channel
@@ -327,11 +354,19 @@
       channel_attributes = 5;

   // The top 10 videos for the channel.
-  repeated google.ads.googleads.v22.common.AudienceInsightsAttributeMetadata
+  repeated google.ads.googleads.v23.common.AudienceInsightsAttributeMetadata
       top_videos = 8;

+  // The languages associated with the content made by a channel.
+  repeated LanguageDistribution language_distributions = 15;
+
   // Metadata string associated with the type of channel.
   string channel_type = 6;
+
+  // The relevance score of the channel to the topic being searched for weighted
+  // by views. The value is between 0 and 1, with 1 being the most relevant.
+  // Only populated for trends using search_topics.
+  double relevance_score = 16;
 }

 // A collection of audience attributes that describe an audience of viewers.
@@ -340,9 +375,30 @@
   // Required. Audience attributes that describe an audience of viewers. This is
   // used to search for topics trending for the defined audience. Attributes
   // age_range, gender, user_interest, entity, category, parental_status, and
-  // income_range are supported.
-  repeated google.ads.googleads.v22.common.AudienceInsightsAttribute
+  // income_range are supported. Attributes user_interest, entity, and category
+  // can only be set in audience_attributes when audience_combinations is
+  // unused.
+  repeated google.ads.googleads.v23.common.AudienceInsightsAttribute
       audience_attributes = 1 [(google.api.field_behavior) = REQUIRED];
+
+  // Optional. A list of audience attribute groups consisting of one or more
+  // Knowledge Graph entities, Product & Service Categories and user interests
+  // that describes an audience. The groups have a logical AND-of-ORs structure:
+  //
+  // 1. Attributes within each InsightsAudienceAttributeGroup are combined
+  // with OR.
+  //
+  // 2. The groups themselves are combined together with AND.
+  //
+  // For example, an audience (Interest A OR Interest B) AND (Entity C) is
+  // represented using two groups. The first group contains the two interests
+  // and the second group contains the entity.
+  //
+  // This field cannot be set if any Knowledge Graph entities, Product &
+  // Service Categories, or user interests are specified in
+  // audience_attributes.
+  repeated google.ads.googleads.v23.common.InsightsAudienceAttributeGroup
+      audience_combinations = 2 [(google.api.field_behavior) = OPTIONAL];
 }

 // A collection of content topics to return trend information for.
@@ -360,15 +416,24 @@
 // A trend insight for a given attribute.
 message TrendInsight {
   // The attribute this trend is for.
-  google.ads.googleads.v22.common.AudienceInsightsAttributeMetadata
+  google.ads.googleads.v23.common.AudienceInsightsAttributeMetadata
       trend_attribute = 1;

   // Metrics associated with this trend. These metrics are for the latest
   // available month and the comparison period is 3 months.
   TrendInsightMetrics trend_metrics = 2;

-  // The direction of trend (such as RISING or DECLINING).
-  google.ads.googleads.v22.enums.InsightsTrendEnum.InsightsTrend trend = 3;
+  // Indicate if a trend is sustained or emerging. Use
+  // trend_metrics.trend_change_percent to determine the direction of the
+  // trend.
+  google.ads.googleads.v23.enums.InsightsTrendEnum.InsightsTrend trend = 3;
+
+  // 3 years of historical data for the trend, including the most recent month
+  // the TrendInsight represents. Each data point represents 1 month of data and
+  // the comparison period is 1 month. The data points are ordered from most
+  // recent month to least recent month. Only populated for trends using
+  // search_topics.
+  repeated TrendInsightDataPoint trend_data_points = 6;

   // Related videos for this topic. Only populated for trends using
   // search_topics.
@@ -382,12 +447,44 @@

 // Metrics associated with a trend insight.
 message TrendInsightMetrics {
   // The number of views for this trend. This is only populated for SearchTopics
   // requests.
   int64 views_count = 1;

+  // Views value normalized to be in the range 0-100. This is only populated for
+  // SearchTopics requests.
+  int64 views_indexed_value = 4;
+
   // The fraction (from 0 to 1 inclusive) of the requested audience that has
   // has searched or viewed this trend. This is only populated for
   // SearchAudience requests.
   double audience_share = 2;
+
+  // The percentage of the change in the trend's value over the comparison
+  // period, where 1.0 represents 100%. If this is 0, it means that the trend is
+  // emerging (new) or sustained (existing but unchanged).
+  double trend_change_percent = 3;
+}
+
+// Trend data for a specific month.
+message TrendInsightDataPoint {
+  // The month that the trend data point represents in the string format
+  // "YYYY-MM".
+  string month = 1;
+
+  // Metrics associated with this trend and month. The comparison period for
+  // these metrics is 1 month.
+  TrendInsightMetrics trend_metrics = 2;
+}
+
+// Languages that pertain to a YouTube channel based on the channel content.
+// Only languages above a certain proportion threshold are included.
+message LanguageDistribution {
+  // [Language
+  // code](https://developers.google.com/google-ads/api/reference/data/codes-formats#languages)
+  // of the language for the YouTube channel.
+  string language_code = 1;
+
+  // The proportion (between 0 and 1)  of the channel's videos in the language.
+  double proportion = 2;
 }
@@ -382,12 +447,44 @@
 // Metrics associated with a trend insight.
 message TrendInsightMetrics {
-  // The number of views for this trend. This is only populated for SearchTopics
-  // requests.
+  // The number of views for this trend. This is only populated for the latest
+  // month of data for SearchTopics requests.
   int64 views_count = 1;
